# Examples for the XPS

Here, you can find working examples of XPS-to-NeXus conversion using the latest [NXmpes](https://fairmat-nfdi.github.io/nexus_definitions/classes/contributed_definitions/NXmpes.html#nxmpes) application definition and the latest development version of [pynxtools-xps](https://github.com/FAIRmat-NFDI/pynxtools-xps).

This reader supports converting X-ray photoelectron spectroscopy into a NeXus formatted file. You can find examples for the supported file formats in the individual subfolders.

## Existing examples
- .sle: [SpecsLabProdigy](https://www.specs-group.com/nc/specs/products/detail/prodigy/) file, propietary format of SPECS GmbH (software version: v1.6)
- .xml: SpecsLab 2files, XML format from SPECS GmbH (software version: v4.63)
- .vms: VAMAS files, ISO standard data transfer format ([ISO 14976](https://www.iso.org/standard/24269.html)), in regular format
- .xy: SpecsLabProdigy export format in XY format (including all export settings)
- .txt:
  - exported by [Scienta Omicron](https://scientaomicron.com/en) instruments
  - exported by [CasaXPS](https://www.casaxps.com/) analysis software

## Contact person in FAIRmat for these example
Lukas Pielsticker